/*
 * config.h - This file is part of ncidd.
 *
 * Copyright (c) 2005-2019
 * by John L. Chmielewski <jlc@users.sourceforge.net>
 *
 * ncidd is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * ncidd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ncidd.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _CONFIG_H
#define _CONFIG_H

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <ctype.h>
#include "logmsg.h"
#include <errno.h>

#define WORDZERO    0x00
#define WORDFLAG    0x01
#define WORDSTR     0x10
#define WORDNUM     0x20
#define WORDFONT    0x40

#define ON          1
#define OFF         0

#define ERRCMD      "unknown command:"
#define ERRWORD     "unknown word:"
#define ERRARG      "missing argument for word:"
#define ERREQA      "missing '=' after word:"
#define ERREQB      "missing '=' before word:"
#define ERRMISS     "missing:"
#define ERRNUM      "invalid number:"
#define ERRPORT     "invalid port number:"

struct setword
{
    const char *word;
    int type;
    const char **buf;
    int *value;
    int min;
    int max;
};

struct sendclient
{
    const char *word;
    int *value;
};

extern const char * config;
extern int ignoreConfWord;	/* if==1 setword can be a subset of the config lines */
extern int errorStatus;
extern int inQuotes;
extern struct setword setword[];
extern struct sendclient sendclient[];
const char * getWord(const char * nameptr, const char * inptr, char * wdptr, int lc);
int doConf(void);
int findWord(const char * wdptr);
int findSend(const char * wdptr);
void configError(const char * file, int lc, const char * word, const char * mesg);
int resetConfEntries(struct setword * new_setwords);

#endif /* config.h */
