/*
 * dopid.c - This file is part of ncidd.
 *
 * Copyright (c) 2017-2018
 * by John L. Chmielewski <jlc@users.sourceforge.net>
 *
 * dopid is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * dopid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ncidd.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "dopid.h"

/*
 * if PID file exists and PID in process table, ERROR
 * if PID file exists and PID not in process table, replace PID file
 * if no PID file, write one
 * if write a pidfile failed, OK
 * If pidfile == 0, do not write PID file
 */
int doPID(pid_t *pid, const char * pidfile)
{
    struct stat statbuf;
    FILE *pidptr;
    pid_t curpid, foundpid = 0;
    int ret;

    /* if pidfile == 0, no pid file is wanted */
    if (pidfile == 0)
    {
        logMsg(LEVEL1, "Not using PID file, there was no '-P' option.\n");
        return 0;
    }

    /* check PID file */
    curpid = getpid();
    if (stat(pidfile, &statbuf) == 0)
    {
        if ((pidptr = fopen(pidfile, "r")) == NULL) return 1;
        ret = fscanf(pidptr, "%u", &foundpid);
        fclose(pidptr);
        if (foundpid) ret = kill(foundpid, 0);
        if (ret == 0 || (ret == -1 && errno != ESRCH)) return 1;
        logMsg(LEVEL1, "Found stale pidfile: %s\n", pidfile);
    }

    /* create pidfile */
    if ((pidptr = fopen(pidfile, "w")) == NULL)
    {
        logMsg(LEVEL1, "Cannot write %s: %s\n", pidfile, strerror(errno));
    }
    else
    {
        *pid = curpid;
        fprintf(pidptr, "%d\n", *pid);
        fclose(pidptr);
        logMsg(LEVEL1, "Wrote pid %d in pidfile: %s\n", *pid, pidfile);
    }

    return 0;
}
