/*
 * strmatch.h - This file is part of ncidd.
 *
 * Copyright (c) 2005-2023
 * by John L. Chmielewski <jlc@users.sourceforge.net>
 *
 * ncidd is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * ncidd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ncidd.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _STRMATCH_H
#define _STRMATCH_H

#include <string.h>
#include <regex.h>
#define PCRE2_CODE_UNIT_WIDTH 8
#include <pcre2.h>   /* Perl regular expressions */

extern pcre2_match_data * pcreMatchData;
extern int pcreErrorNumber;
extern PCRE2_SIZE pcreErrorOffset;

/* remember features of an ncid simple expression
 * for later calls to strmatch() with regex=0
 */
struct abwstr {
   char skip1;     /* flag for ^1? */
   char beginstar; /* flag for leading * */
   char allstar;   /* flag only a star to match anything  */
   char endstar;   /* flag for trailing * */
   int len;        /* length of the match string */
   char * match;   /* the remaining string to be matched */
};

extern int regex, ignore1;

int strmatch(const char * string, void * regexp);

struct abwstr * store_astrmatch(const char * string);
struct abwstr * store_bwstrmatch(const char * string);
void free_abwstr(struct abwstr * ncidreg);


#endif /* strmatch.h */
