/*
 * nciddalias.h - This file is part of ncidd.
 *
 * Copyright (c) 2005-2022
 * by John L. Chmielewski <jlc@users.sourceforge.net>
 *
 * ncidd is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * ncidd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ncidd.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _NCIDDALIAS_H
#define _NCIDDALIAS_H

#include <stdio.h>
#include <string.h>
#include <sys/types.h>
#include <regex.h>
#define PCRE2_CODE_UNIT_WIDTH 8
#include <pcre2.h>   /* Perl regular expressions */

#ifndef CIDALIAS
#define CIDALIAS     "/etc/ncid/ncidd.alias"
#endif

#define CIDSIZE      256
#define NMBRNAME     0x01
#define NMBRONLY     0x10
#define NMBRDEP      0x11
#define NAMEONLY     0x20
#define NAMEDEP      0x21
#define LINEONLY     0x40

#define NMBRNAME_TXT "NMBRNAME"
#define NMBRONLY_TXT "NMBRONLY"
#define NMBRDEP_TXT  "NMBRDEP"
#define NAMEONLY_TXT "NAMEONLY"
#define NAMEDEP_TXT  "NAMEDEP"
#define LINEONLY_TXT "LINEONLY"
#define NOALIAS_TXT  "NOALIAS"

#define ERRIF        "missing 'if' before word:"
#define ERRLONG      "word is too long:"

struct alias_info
{
    int type;
    int matched;
    char * type_txt;
    char * from;
    char * to;
    char * depend;
    struct abwstr * ncidreg;
    regex_t * preg;
    pcre2_code * pcreg;
};

struct alias
{
    struct alias_info info;
    struct alias *next;
};

extern char * progname;
extern const char * cidalias;

int readAliasFile(void);
char * findAlias(const char * name, const char * nmbr, const char * line);
void builtinAlias(char * to, const char * from);
void userAlias(char * nmbr, char * name, char * line);
void rmaliases(void);
void showAliasScores(void);
char * starfree(const char * src, size_t clipsiz);

#endif /* nciddalias.h */
