/*
 * nciddhangup.h - This file is part of ncidd.
 *
 * Copyright (c) 2005-2024
 * by John L. Chmielewski <jlc@users.sourceforge.net>
 *
 * ncidd is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * ncidd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ncidd.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _NCIDDHANGUP_H
#define _NCIDDHANGUP_H

#include <sys/types.h>
#include <regex.h>
#define PCRE2_CODE_UNIT_WIDTH 8
#include <pcre2.h>   /* Perl regular expressions */


#ifndef BLACKLIST
#define BLACKLIST   "/etc/ncid/ncidd.blacklist"
#endif

#ifndef WHITELIST
#define WHITELIST   "/etc/ncid/ncidd.whitelist"
#endif

#define ENTRYSIZE   180 /* maximum size of a list entry */

typedef struct list
{
    char * entry;	        /* a caller name or number */
    char * newname;	        /* the #= substitute name, if any */
    struct list * next;
    struct abwstr * ncidreg;	/* the ncid expression caller */
    regex_t * preg;		/* the regex caller */
    pcre2_code * pcreg;		/* the pcre caller */
} list_t;

/* return structure from onList() */
struct retbw {
    int ret;
    const char * entry;
};

extern const char * blacklist;  /* name of the file */
extern const char * whitelist;  /* name of the file */
extern const char * listname;   /* #= the newname from the entry */
extern int regex;

void rmBWlists(void);
int readBWlists(void);
int doList(const char * filename, list_t **listHead, list_t **listCurrent);
struct retbw onBlackWhite (const char * namep, const char * nmbrp);
struct retbw checkWhitelist(const char * namep, const char * nmbrp);
struct retbw checkBlacklist(const char * namep, const char * nmbrp);

#endif /* nciddhangup.h */
